@@ -2,7 +2,7 @@ from mowl.walking.walking import WalkingModel
 import random
 import os
 import logging
-
+import tempfile
 from org.mowl.Walking import DeepWalk as DW
 from java.util import HashMap
 from java.util import ArrayList
@@ -23,10 +23,13 @@ class DeepWalk(WalkingModel):
                  num_walks,
                  walk_length,
                  alpha,
-                 outfile,
+                 outfile = None,
                  workers=1,
 ):
 
+        if outfile is None:
+            tmp_file = tempfile.NamedTemporaryFile()
+            outfile = tmp_file.name
         super().__init__(num_walks, walk_length, outfile, workers)
 
         self.alpha = alpha
